# -*- coding: utf-8 -*-
# Generated by Django 1.11.6 on 2018-10-11 19:22
from __future__ import unicode_literals

import django.utils.timezone
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('depayco', '0003_auto_20181011_1421'),
    ]

    operations = [
        migrations.AddField(
            model_name='subscription',
            name='current_period_end',
            field=models.DateTimeField(default=django.utils.timezone.now),
            preserve_default=False,
        ),
    ]
