# -*- coding: utf-8 -*-
# Generated by Django 1.11.6 on 2018-10-11 21:20
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('depayco', '0004_subscription_current_period_end'),
    ]

    operations = [
        migrations.AlterField(
            model_name='subscription',
            name='current_period_end',
            field=models.DateField(),
        ),
        migrations.AlterField(
            model_name='subscription',
            name='current_period_start',
            field=models.DateField(),
        ),
    ]
