INTERVAL = (
    ('day', 'Day'),
    ('week', 'Week'),
    ('month', 'Month'),
    ('year', 'Year'),
)

IDENTIFICATION_TYPE = (
    ('cc', 'Cédula de ciudadanía'),
    ('ce', 'Cédula de extranjería '),
    ('nit', 'Número de Identificación Tributaria'),
    ('dni', 'Documento nacional de identidad'),
)
