# -*- coding: utf-8 -*-
# Generated by Django 1.11.6 on 2018-10-11 19:21
from __future__ import unicode_literals

import django.utils.timezone
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('depayco', '0002_subscription_is_active'),
    ]

    operations = [
        migrations.AddField(
            model_name='subscription',
            name='current_period_start',
            field=models.DateTimeField(default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='customer',
            name='identification_type',
            field=models.CharField(choices=[('cc', 'Cédula de ciudadanía'), ('ce', 'Cédula de extranjería '), ('nit', 'Número de Identificación Tributaria'), ('dni', 'Documento nacional de identidad')], max_length=5),
        ),
    ]
